#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-socks
version:              0.6.2
visibility:           public
id:                   crypton-socks-0.6.2-15CTDOCZVLdKoWgX7nuAab
key:                  crypton-socks-0.6.2-15CTDOCZVLdKoWgX7nuAab
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:
    Mike Pilgrem <public@pilgrem.com>,
    Kazu Yamamoto <kazu@iij.ad.jp>

author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/mpilgrem/crypton-socks
synopsis:             SOCKS Protocol Version 5
description:          A library implementing SOCKS Protocol Version 5.
category:             Network
abi:                  7b3b913dd73d1f11cd3f887c08ae8e5a
exposed:              True
exposed-modules:
    Network.Socks5 Network.Socks5.Lowlevel Network.Socks5.Types

hidden-modules:
    Network.Socks5.Command Network.Socks5.Conf Network.Socks5.Parse
    Network.Socks5.Wire

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-socks-0.6.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-socks-0.6.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-socks-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-socks
hs-libraries:         HScrypton-socks-0.6.2-15CTDOCZVLdKoWgX7nuAab
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    network-3.1.4.0-DnyUe3C7n48FET4frYkCJy

haddock-interfaces:
    /usr/share/doc/haskell-crypton-socks/html/crypton-socks.haddock

haddock-html:         /usr/share/doc/haskell-crypton-socks/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

